##  Identify Applications
To identify applications for modernization, follow these steps:
  1. In your inventory, filter for application fact sheets. They will be the core of your assessment.
If you’re planning a cloud migration, for example, use the Hosting Type filter to view on-premise applications. This will hide applications that already run in the cloud.
  2. Use the Lifecycle filter to narrow your scope to applications that will remain active beyond the end of the year.
  3. After you select the lifecycle, choose End of year under point in time.
  4. Filter by TIME classification.
Focus on applications classified under Invest and Migrate in the TIME model. These are the most suitable for cloud migration. Avoid applications marked as Eliminate, and consider Tolerate applications for future assessments.
**Tip**
If you haven't classified your applications based on the TIME framework, learn how in [Gartner® TIME Framework](https://help.sap.com/docs/leanix/ea/time?locale=en-US&state=PRODUCTION&version=CLOUD).


Identifying Applications in the Inventory
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio25d178665ae7485abeb988a811433f9e_LowRes.png)
